@@ -1,20 +1,15 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import
 
 import argparse
 from textwrap import dedent
 
-import logbook
-
 from ._const import TcCommandOutput, TrafficDirection
 
 
-class ArgparseWrapper(object):
+class ArgparseWrapper:
     """
     Wrapper class for argparse
     """
@@ -107,16 +102,16 @@ class ArgparseWrapper(object):
             "--debug",
             dest=dest,
             action="store_const",
-            const=logbook.DEBUG,
-            default=logbook.INFO,
+            const="DEBUG",
+            default="INFO",
             help="for debug print.",
         )
         group.add_argument(
             "--quiet",
             dest=dest,
             action="store_const",
-            const=logbook.NOTSET,
-            default=logbook.INFO,
+            const="QUIET",
+            default="INFO",
             help="suppress execution log messages.",
         )
 
