@@ -1,10 +1,7 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 import errno
 import os
@@ -13,7 +10,6 @@ import sys
 from collections import namedtuple
 
 import msgfy
-import six
 from docker import APIClient
 from docker.errors import APIError, NotFound
 from path import Path
@@ -28,11 +24,7 @@ from ._error import ContainerNotFoundError
 from ._logger import logger
 
 
-if six.PY2:
-    PermissionError = OSError
-
-
-ContainerInfo = namedtuple("ContainerInfo", "id name pid ipaddr image")
+ContainerInfo = namedtuple("ContainerInfo", "id name pid ipaddr image state")
 
 
 class IfIndex(Model):
@@ -42,7 +34,7 @@ class IfIndex(Model):
     peer_ifindex = Integer(not_null=True, unique=True)
 
 
-class DockerClient(object):
+class DockerClient:
     @property
     def __netns_root_path(self):
         return Path("/var/run/netns")
@@ -95,19 +87,19 @@ class DockerClient(object):
 
         container_name = container_map["Name"].lstrip("/")
         container_state = container_map["State"]
-
-        if not container_state["Running"]:
-            logger.error("{} not running".format(container_name))
-            return ContainerInfo(name=container_name)
-
-        return ContainerInfo(
+        container_info = ContainerInfo(
             id=container_map["Id"],
             name=container_name,
             pid=int(container_state["Pid"]),
             ipaddr=container_map["NetworkSettings"]["IPAddress"],
             image=container_map["Config"]["Image"],
+            state=namedtuple("ContainerState", (k.lower() for k in container_state.keys()))(
+                *container_state.values()
+            ),
         )
 
+        return container_info
+
     def create_veth_table(self, container):
         try:
             self.__netns_root_path.makedirs_p()
@@ -142,15 +134,14 @@ class DockerClient(object):
 
     def select_veth(self, container_name):
         for container_record in IfIndex.select(where=Where("host", container_name)):
-            for veth_record in IfIndex.select(
+            yield from IfIndex.select(
                 where=And(
                     [
                         Where("host", self.__host_name),
                         Where("ifindex", container_record.peer_ifindex),
                     ]
                 )
-            ):
-                yield veth_record
+            )
 
     def fetch_veth_list(self, container_name):
         return [veth_record.ifname for veth_record in self.select_veth(container_name)]
