@@ -1,15 +1,13 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
 
-import six
+import humanreadable as hr
 import typepy
+from pyroute2 import IPRoute
 
-from ._const import KILO_SIZE, Network
+from ._const import Network
 from ._error import NetworkInterfaceNotFoundError
 
 
@@ -31,13 +29,11 @@ def _get_iproute2_upper_limite_rate():
     :rtype: int
     """
 
-    from ._converter import HumanReadableBits
-
     # upper bandwidth rate limit of iproute2 was 34,359,738,360
     # bits per second older than 3.14.0
     # http://git.kernel.org/cgit/linux/kernel/git/shemminger/iproute2.git/commit/?id=8334bb325d5178483a3063c5f06858b46d993dc7
 
-    return HumanReadableBits("32G", kilo_size=KILO_SIZE).to_kilobits()
+    return hr.BitPerSecond("32Gbps")
 
 
 def _read_iface_speed(tc_device):
@@ -45,20 +41,21 @@ def _read_iface_speed(tc_device):
         return int(f.read().strip())
 
 
-def get_no_limit_kbits(tc_device):
+def get_upper_limit_rate(tc_device):
     if typepy.is_null_string(tc_device):
         return _get_iproute2_upper_limite_rate()
 
     try:
         speed_value = _read_iface_speed(tc_device)
-    except IOError:
+    except OSError:
         return _get_iproute2_upper_limite_rate()
 
     if speed_value < 0:
         # default to the iproute2 upper limit when speed value is -1 in
         # paravirtualized network interfaces
         return _get_iproute2_upper_limite_rate()
-    return min(speed_value * KILO_SIZE, _get_iproute2_upper_limite_rate())
+
+    return min(hr.BitPerSecond("{}Mbps".format(speed_value)), _get_iproute2_upper_limite_rate())
 
 
 def is_anywhere_network(network, ip_version):
@@ -101,24 +98,22 @@ def sanitize_network(network, ip_version):
     # validate network str ---
 
     if ip_version == 4:
-        return ipaddress.IPv4Network(six.text_type(network)).compressed
+        return ipaddress.IPv4Network(str(network)).compressed
 
     if ip_version == 6:
-        return ipaddress.IPv6Network(six.text_type(network)).compressed
+        return ipaddress.IPv6Network(str(network)).compressed
 
     raise ValueError("unexpected ip version: {}".format(ip_version))
 
 
 def verify_network_interface(device, tc_command_output):
-    try:
-        import netifaces
-    except ImportError:
-        return
-
     from ._common import is_execute_tc_command
 
     if not is_execute_tc_command(tc_command_output):
         return
 
-    if device not in netifaces.interfaces():
+    with IPRoute() as ipr:
+        avail_interfaces = [link.get_attr("IFLA_IFNAME") for link in ipr.get_links()]
+
+    if device not in avail_interfaces:
         raise NetworkInterfaceNotFoundError(target=device)
