@@ -1,33 +1,27 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import ipaddress
 import re
-from collections import OrderedDict
 
 import pyparsing as pp
-import simplejson as json
 import typepy
-from six import text_type
 
-from ._interface import AbstractParser
 from .._const import Tc, TcSubCommand
 from .._logger import logger
 from .._network import sanitize_network
+from ._interface import AbstractParser
+from ._model import Filter
 
 
 class TcFilterParser(AbstractParser):
-    class FilterMatchIdIpv4(object):
+    class FilterMatchIdIpv4:
         INCOMING_NETWORK = 12
         OUTGOING_NETWORK = 16
         PORT = 20
 
-    class FilterMatchIdIpv6(object):
+    class FilterMatchIdIpv6:
         INCOMING_NETWORK_LIST = [8, 12, 16, 20]
         OUTGOING_NETWORK_LIST = [24, 28, 32, 36]
         PORT = 40
@@ -64,9 +58,8 @@ class TcFilterParser(AbstractParser):
         return TcSubCommand.FILTER.value
 
     def __init__(self, con, ip_version):
-        super(TcFilterParser, self).__init__()
+        super().__init__(con)
 
-        self.__con = con
         self.__ip_version = ip_version
         self.__buffer = None
         self.__parse_idx = 0
@@ -81,7 +74,6 @@ class TcFilterParser(AbstractParser):
         if typepy.is_null_string(text):
             return []
 
-        filter_data_matrix = []
         self.__buffer = self._to_unicode(text).splitlines()
         self.__parse_idx = 0
 
@@ -99,12 +91,14 @@ class TcFilterParser(AbstractParser):
             except pp.ParseException:
                 logger.debug("failed to parse mangle: {}".format(line))
             else:
-                filter_data_matrix.append(
-                    {
-                        Tc.Param.DEVICE: self.__device,
-                        Tc.Param.CLASS_ID: self.__classid,
-                        Tc.Param.HANDLE: self.__handle,
-                    }
+                Filter.insert(
+                    Filter(
+                        **{
+                            Tc.Param.DEVICE: self.__device,
+                            Tc.Param.CLASS_ID: self.__classid,
+                            Tc.Param.HANDLE: self.__handle,
+                        }
+                    )
                 )
                 self._clear()
                 continue
@@ -117,9 +111,9 @@ class TcFilterParser(AbstractParser):
                 self.__parse_priority(line)
                 self.__parse_filter_id(line)
 
-                if tc_filter.get(Tc.Param.FLOW_ID):
+                if tc_filter.flowid:
                     logger.debug("store filter: {}".format(tc_filter))
-                    filter_data_matrix.append(tc_filter)
+                    Filter.insert(tc_filter)
                     self._clear()
 
                     self.__parse_flow_id(line)
@@ -142,20 +136,7 @@ class TcFilterParser(AbstractParser):
                 logger.debug("failed to parse filter: {}".format(line))
 
         if self.__flow_id:
-            filter_data_matrix.append(self.__get_filter())
-
-        if filter_data_matrix:
-            self.__con.create_table_from_data_matrix(
-                self._tc_subcommand, list(self.__get_filter()), filter_data_matrix
-            )
-
-        logger.debug(
-            "tc {:s} parse result: {}".format(
-                self._tc_subcommand, json.dumps(filter_data_matrix, indent=4)
-            )
-        )
-
-        return filter_data_matrix
+            Filter.insert(self.__get_filter())
 
     def parse_incoming_device(self, text):
         if typepy.is_null_string(text):
@@ -184,22 +165,17 @@ class TcFilterParser(AbstractParser):
         self.__classid = None
 
     def __get_filter(self):
-        tc_filter = OrderedDict()
-        tc_filter[Tc.Param.DEVICE] = self.__device
-        tc_filter[Tc.Param.FILTER_ID] = self.__filter_id
-        tc_filter[Tc.Param.FLOW_ID] = self.__flow_id
-        tc_filter[Tc.Param.PROTOCOL] = self.protocol
-        tc_filter[Tc.Param.PRIORITY] = self.__priority
-        tc_filter[Tc.Param.SRC_NETWORK] = sanitize_network(
-            self.__filter_src_network, self.__ip_version
+        return Filter(
+            device=self.__device,
+            filter_id=self.__filter_id,
+            flowid=self.__flow_id,
+            protocol=self.protocol,
+            priority=self.__priority,
+            src_network=sanitize_network(self.__filter_src_network, self.__ip_version),
+            dst_network=sanitize_network(self.__filter_dst_network, self.__ip_version),
+            src_port=self.__filter_src_port,
+            dst_port=self.__filter_dst_port,
         )
-        tc_filter[Tc.Param.DST_NETWORK] = sanitize_network(
-            self.__filter_dst_network, self.__ip_version
-        )
-        tc_filter[Tc.Param.SRC_PORT] = self.__filter_src_port
-        tc_filter[Tc.Param.DST_PORT] = self.__filter_dst_port
-
-        return tc_filter
 
     def __parse_flow_id(self, line):
         parsed_list = self.__FILTER_FLOWID_PATTERN.parseString(line)
@@ -244,9 +220,7 @@ class TcFilterParser(AbstractParser):
         return (value_hex, mask_hex, match_id)
 
     def __parse_filter_ipv4_network(self, value_hex, mask_hex, match_id):
-        ipaddr = ".".join(
-            [text_type(int(value_hex[i : i + 2], 16)) for i in range(0, len(value_hex), 2)]
-        )
+        ipaddr = ".".join([str(int(value_hex[i : i + 2], 16)) for i in range(0, len(value_hex), 2)])
         netmask = bin(int(mask_hex, 16)).count("1")
         network = "{:s}/{:d}".format(ipaddr, netmask)
 
@@ -255,7 +229,7 @@ class TcFilterParser(AbstractParser):
         elif match_id == self.FilterMatchIdIpv4.OUTGOING_NETWORK:
             self.__filter_dst_network = network
         else:
-            logger.warn("unknown match id: {}".format(match_id))
+            logger.warning("unknown match id: {}".format(match_id))
 
     def __parse_filter_ipv6_network(self, value_hex, mask_hex, match_id):
         from collections import namedtuple
@@ -326,10 +300,10 @@ class TcFilterParser(AbstractParser):
             dst_octet_list.append("0000")
 
         self.__filter_dst_network = ipaddress.IPv6Network(
-            "{:s}/{:d}".format(":".join(dst_octet_list), dst_netmask)
+            "{:s}/{:d}".format(":".join(dst_octet_list), dst_netmask), strict=False
         ).compressed
         self.__filter_src_network = ipaddress.IPv6Network(
-            "{:s}/{:d}".format(":".join(src_octet_list), src_netmask)
+            "{:s}/{:d}".format(":".join(src_octet_list), src_netmask), strict=False
         ).compressed
 
     def __parse_filter_port(self, value_hex):
@@ -368,7 +342,7 @@ class TcFilterParser(AbstractParser):
             + self.FilterMatchIdIpv6.OUTGOING_NETWORK_LIST
             + [self.FilterMatchIdIpv6.PORT]
         ):
-            logger.warn(
+            logger.warning(
                 "unknown match id for an IPv4 filter: might be an IPv6 filter. "
                 "try to use --ipv6 option. (id={})".format(match_id)
             )
