@@ -1,31 +1,31 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import re
 
 import pyparsing as pp
-import simplejson as json
 import typepy
 
-from ._interface import AbstractParser
 from .._const import Tc, TcSubCommand
 from .._logger import logger
+from ._interface import AbstractParser
+from ._model import Qdisc
 
 
 class TcQdiscParser(AbstractParser):
+    __RE_DIRECT_QLEN = re.compile("direct_qlen (?P<number>[0-9]+)")
+
     @property
     def _tc_subcommand(self):
         return TcSubCommand.QDISC.value
 
-    def __init__(self, con):
-        super(TcQdiscParser, self).__init__()
+    def __parse_direct_qlen(self, line):
+        m = self.__RE_DIRECT_QLEN.search(line)
+        if m is None:
+            return
 
-        self.__con = con
+        self.__parsed_param["direct_qlen"] = int(m.group("number"))
 
     def parse(self, device, text):
         self._clear()
@@ -34,7 +34,6 @@ class TcQdiscParser(AbstractParser):
             return []
 
         text = text.strip()
-        entry_list = []
 
         for line in text.splitlines():
             if typepy.is_null_string(line):
@@ -42,12 +41,14 @@ class TcQdiscParser(AbstractParser):
 
             line = self._to_unicode(line.lstrip())
 
-            if re.search("qdisc netem|qdisc tbf", line) is None:
+            if re.search("^qdisc netem |^qdisc htb |^qdisc tbf ", line) is None:
                 continue
 
-            self._clear()
+            if re.search("^qdisc htb ", line) is not None:
+                self.__parse_direct_qlen(line)
+                continue
 
-            if re.search("qdisc netem", line) is not None:
+            if re.search("^qdisc netem ", line) is not None:
                 self.__parse_netem_param(line, "parent", pp.hexnums + ":")
 
             self.__parsed_param[Tc.Param.DEVICE] = device
@@ -61,31 +62,10 @@ class TcQdiscParser(AbstractParser):
             self.__parse_bandwidth_rate(line)
 
             logger.debug("parse a qdisc entry: {}".format(self.__parsed_param))
-            entry_list.append(self.__parsed_param)
 
-        if entry_list:
-            self.__con.create_table_from_data_matrix(
-                self._tc_subcommand,
-                [
-                    Tc.Param.DEVICE,
-                    "parent",
-                    "handle",
-                    "delay",
-                    "delay-distro",
-                    "loss",
-                    "duplicate",
-                    "corrupt",
-                    "reorder",
-                    "rate",
-                ],
-                entry_list,
-            )
+            Qdisc.insert(Qdisc(**self.__parsed_param))
 
-        logger.debug(
-            "tc {:s} parse result: {}".format(self._tc_subcommand, json.dumps(entry_list, indent=4))
-        )
-
-        return entry_list
+            self._clear()
 
     def _clear(self):
         self.__parsed_param = {}
