@@ -1,29 +1,27 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, division, unicode_literals
 
 import errno
 import re
+from typing import List
 
 import typepy
 
-from ._interface import AbstractShaper
 from .._common import is_execute_tc_command, logging_context, run_command_helper
 from .._const import ShapingAlgorithm, TcSubCommand
 from .._error import TcAlreadyExist
 from .._logger import logger
-from .._network import get_no_limit_kbits
+from .._network import get_upper_limit_rate
 from .._tc_command_helper import run_tc_show
+from ._interface import AbstractShaper
 
 
 class HtbShaper(AbstractShaper):
     __DEFAULT_CLASS_MINOR_ID = 1
 
-    class MinQdiscMinorId(object):
+    class MinQdiscMinorId:
         OUTGOING = 40
         INCOMING = 20
 
@@ -32,7 +30,7 @@ class HtbShaper(AbstractShaper):
         return ShapingAlgorithm.HTB
 
     def __init__(self, tc_obj):
-        super(HtbShaper, self).__init__(tc_obj)
+        super().__init__(tc_obj)
 
         self.__qdisc_minor_id = None
         self.__qdisc_minor_id_count = 0
@@ -98,11 +96,11 @@ class HtbShaper(AbstractShaper):
         classid = self._get_tc_parent(
             "{:s}:{:d}".format(self._tc_obj.qdisc_major_id_str, self._get_qdisc_minor_id())
         )
-        no_limit_kbits = get_no_limit_kbits(self._tc_device)
+        upper_limit_rate = get_upper_limit_rate(self._tc_device)
 
-        kbits = self._tc_obj.netem_param.bandwidth_rate
-        if kbits is None:
-            kbits = no_limit_kbits
+        bandwidth = self._tc_obj.netem_param.bandwidth_rate
+        if bandwidth is None:
+            bandwidth = upper_limit_rate
 
         command_item_list = [
             base_command,
@@ -110,13 +108,16 @@ class HtbShaper(AbstractShaper):
             "parent {:s}".format(parent),
             "classid {:s}".format(classid),
             self.algorithm_name,
-            "rate {}Kbit".format(kbits),
-            "ceil {}Kbit".format(kbits),
+            "rate {}Kbit".format(bandwidth.kilo_bps),
+            "ceil {}Kbit".format(bandwidth.kilo_bps),
         ]
 
-        if kbits != no_limit_kbits:
+        if bandwidth != upper_limit_rate:
             command_item_list.extend(
-                ["burst {}KB".format(kbits / (10 * 8)), "cburst {}KB".format(kbits / (10 * 8))]
+                [
+                    "burst {}KB".format(bandwidth.kilo_byte_per_sec),
+                    "cburst {}KB".format(bandwidth.kilo_byte_per_sec),
+                ]
             )
 
         run_command_helper(
@@ -158,7 +159,7 @@ class HtbShaper(AbstractShaper):
             self._dev,
             "protocol {:s}".format(self._tc_obj.protocol),
             "parent {:s}:".format(self._tc_obj.qdisc_major_id_str),
-            "prio 1",
+            "prio {:d}".format(self._get_filter_prio(is_exclude_filter=True)),
             "u32",
         ]
 
@@ -263,27 +264,31 @@ class HtbShaper(AbstractShaper):
 
         return next_minor_id
 
-    def __get_unique_netem_major_id(self):
-        exist_netem_item_list = re.findall(
+    def __extract_exist_netem_major_ids(self) -> List[int]:
+        exist_netem_items = re.findall(
             "qdisc [a-z]+ [a-z0-9]+",
             run_tc_show(TcSubCommand.QDISC, self._tc_device, self._tc_obj.tc_command_output),
             re.MULTILINE,
         )
 
+        logger.debug("existing netem list with {:s}: {}".format(self._dev, exist_netem_items))
+
         exist_netem_major_id_list = []
-        for netem_item in exist_netem_item_list:
+        for netem_item in exist_netem_items:
             exist_netem_major_id_list.append(int(netem_item.split()[-1], 16))
 
-        logger.debug("existing netem list with {:s}: {}".format(self._dev, exist_netem_item_list))
+        return exist_netem_major_id_list
+
+    def __get_unique_netem_major_id(self):
+        exist_netem_major_ids = self.__extract_exist_netem_major_ids()
+
         logger.debug(
-            "existing netem major id list with {:s}: {}".format(
-                self._dev, exist_netem_major_id_list
-            )
+            "existing netem major id list with {:s}: {}".format(self._dev, exist_netem_major_ids)
         )
 
         next_netem_major_id = self._tc_obj.netem_param.calc_device_qdisc_major_id()
         while True:
-            if next_netem_major_id not in exist_netem_major_id_list:
+            if next_netem_major_id not in exist_netem_major_ids:
                 break
 
             next_netem_major_id += 1
@@ -319,7 +324,7 @@ class HtbShaper(AbstractShaper):
                     "parent {:s}".format(parent),
                     "classid {:s}".format(classid),
                     self.algorithm_name,
-                    "rate {}kbit".format(get_no_limit_kbits(self._tc_device)),
+                    "rate {}kbit".format(get_upper_limit_rate(self._tc_device).kilo_bps),
                 ]
             ),
             ignore_error_msg_regexp=self._tc_obj.REGEXP_FILE_EXISTS,
