@@ -1,27 +1,25 @@
-#!/usr/bin/env python
-# encoding: utf-8
+#!/usr/bin/env python3
 
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, print_function
 
 import errno
 import sys
 
-import logbook
 import subprocrunner as spr
 
 from .__version__ import __version__
 from ._argparse_wrapper import ArgparseWrapper
 from ._capabilities import check_execution_authority
 from ._common import initialize_cli, is_execute_tc_command, normalize_tc_value
-from ._const import Tc, TcSubCommand
+from ._const import Tc
 from ._error import NetworkInterfaceNotFoundError
 from ._logger import logger, set_logger
 from ._main import Main
 from ._network import verify_network_interface
+from .parser._model import Filter
 from .traffic_control import TrafficControl
 
 
@@ -29,7 +27,7 @@ def parse_option():
     parser = ArgparseWrapper(__version__)
 
     group = parser.parser.add_argument_group("Traffic Control")
-    if set(["-d", "--device"]).intersection(set(sys.argv)):
+    if {"-d", "--device"}.intersection(set(sys.argv)):
         # deprecated: remain for backward compatibility
         group.add_argument("-d", "--device", required=True, help="network device name (e.g. eth0)")
     else:
@@ -62,13 +60,13 @@ class TcDelMain(Main):
 
         for tc_target in self._fetch_tc_targets():
             tc = self.__create_tc_obj(tc_target)
-            if self._options.log_level == logbook.INFO:
-                spr.set_log_level(logbook.ERROR)
+            if self._options.log_level == "INFO":
+                spr.set_log_level("ERROR")
             normalize_tc_value(tc)
 
             try:
                 if is_delete_all:
-                    return_code_list.append(tc.delete_all_tc())
+                    return_code_list.append(0 if tc.delete_all_rules() is True else 1)
                 else:
                     return_code_list.append(tc.delete_tc())
             except NetworkInterfaceNotFoundError as e:
@@ -80,9 +78,10 @@ class TcDelMain(Main):
         return self._get_return_code(return_code_list)
 
     def __create_tc_obj(self, tc_target):
-        from .parser.shaping_rule import TcShapingRuleParser
         from simplesqlite.query import Where
 
+        from .parser.shaping_rule import TcShapingRuleParser
+
         options = self._options
 
         if options.filter_id:
@@ -94,27 +93,17 @@ class TcDelMain(Main):
                 logger=logger,
             )
             shaping_rule_parser.parse()
-            result = shaping_rule_parser.con.select_as_dict(
-                table_name=TcSubCommand.FILTER.value,
-                columns=[
-                    Tc.Param.SRC_NETWORK,
-                    Tc.Param.DST_NETWORK,
-                    Tc.Param.SRC_PORT,
-                    Tc.Param.DST_PORT,
-                ],
-                where=Where(Tc.Param.FILTER_ID, options.filter_id),
-            )
-            if not result:
+            for record in Filter.select(where=Where(Tc.Param.FILTER_ID, options.filter_id),):
+                dst_network = record.dst_network
+                src_network = record.src_network
+                dst_port = record.dst_port
+                src_port = record.src_port
+                break
+            else:
                 logger.error(
                     "shaping rule not found associated with the id ({}).".format(options.filter_id)
                 )
                 sys.exit(1)
-
-            filter_param = result[0]
-            dst_network = filter_param.get(Tc.Param.DST_NETWORK)
-            src_network = filter_param.get(Tc.Param.SRC_NETWORK)
-            dst_port = filter_param.get(Tc.Param.DST_PORT)
-            src_port = filter_param.get(Tc.Param.SRC_PORT)
         else:
             dst_network = self._extract_dst_network()
             src_network = self._extract_src_network()
