@@ -1,18 +1,16 @@
-#!/usr/bin/env python
-# encoding: utf-8
+#!/usr/bin/env python3
 
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import sys
 
 import msgfy
-import simplejson as json
 import subprocrunner as spr
 from docker.errors import DockerException
+from simplesqlite import SimpleSQLite
+from simplesqlite.model import Integer, Model, Text
 
 from .__version__ import __version__
 from ._argparse_wrapper import ArgparseWrapper
@@ -26,11 +24,36 @@ from ._tc_script import write_tc_script
 from .parser.shaping_rule import TcShapingRuleParser
 
 
+try:
+    import ujson as json
+except ImportError:
+    import json  # type: ignore
+
+
+class ShapingRuleModel(Model):
+    device = Text(not_null=True)
+    direction = Text(not_null=True)
+    filter_id = Text(not_null=True)
+    dst_network = Text()
+    dst_port = Integer()
+    src_network = Text()
+    src_port = Integer()
+    protocol = Text(not_null=True)
+
+    delay = Text()
+    delay_distro = Text()
+    loss = Text()
+    duplicate = Text()
+    corrupt = Text()
+    reorder = Text()
+    rate = Text()
+
+
 def parse_option():
     parser = ArgparseWrapper(__version__)
 
     group = parser.parser.add_argument_group("Traffic Control")
-    if set(["-d", "--device"]).intersection(set(sys.argv)):
+    if {"-d", "--device"}.intersection(set(sys.argv)):
         # deprecated: remain for backward compatibility
         group.add_argument(
             "-d", "--device", action="append", required=True, help="network device name (e.g. eth0)"
@@ -54,6 +77,18 @@ def parse_option():
         default=False,
         help="colorize the output. require Pygments package.",
     )
+    parser.parser.add_argument("--export", dest="export_path", help="[experimental]")
+    parser.parser.add_argument(
+        "--exclude-filter-id",
+        action="store_true",
+        default=False,
+        help="[experimental] not display filter_id.",
+    )
+    parser.parser.add_argument(
+        "--dump-db",
+        dest="dump_db_path",
+        help="[experimental] dump parsed results to a SQLite database file",
+    )
 
     return parser.parser.parse_args()
 
@@ -61,8 +96,8 @@ def parse_option():
 def print_tc(text, is_colorize):
     try:
         from pygments import highlight
-        from pygments.lexers import JsonLexer
         from pygments.formatters import TerminalTrueColorFormatter
+        from pygments.lexers import JsonLexer
 
         pygments_installed = True
     except ImportError:
@@ -78,6 +113,18 @@ def print_tc(text, is_colorize):
         print(text)
 
 
+def export_settings(export_path, out_rules, in_rules):
+    with SimpleSQLite(export_path, mode="a") as con:
+        ShapingRuleModel.attach(con)
+        ShapingRuleModel.create()
+
+        for out_rule in out_rules:
+            ShapingRuleModel.insert(ShapingRuleModel(**out_rule))
+
+        for in_rule in in_rules:
+            ShapingRuleModel.insert(ShapingRuleModel(**in_rule))
+
+
 def extract_tc_params(options):
     dclient = None
     if options.use_docker:
@@ -91,33 +138,63 @@ def extract_tc_params(options):
 
     for device in options.device:
         try:
-            if options.use_docker and dclient.exist_container(container=device):
+            if options.use_docker:
                 container = device
-
-                dclient.verify_container(container)
-                dclient.create_veth_table(container)
                 container_info = dclient.extract_container_info(container)
 
+                if not container_info.state.running:
+                    logger.error(
+                        "{id} ({name}) not running (current status: {status})".format(
+                            id=container,
+                            name=container_info.name,
+                            status=container_info.state.status,
+                        )
+                    )
+                    continue
+
+                dclient.create_veth_table(container)
+
                 for veth in dclient.fetch_veth_list(container_info.name):
-                    tc_params.update(
-                        TcShapingRuleParser(
-                            veth, options.ip_version, options.tc_command_output, logger
-                        ).get_tc_parameter()
-                    )
-                    key = "{veth} (container_id={id}, image={image})".format(
-                        veth=veth, id=container_info.id[:12], image=container_info.image
+                    rule_parser = TcShapingRuleParser(
+                        device=veth,
+                        ip_version=options.ip_version,
+                        tc_command_output=options.tc_command_output,
+                        logger=logger,
+                        export_path=options.export_path,
+                        is_parse_filter_id=not options.exclude_filter_id,
+                        dump_db_path=options.dump_db_path,
                     )
+                    rule_parser.parse()
+
+                    if options.export_path:
+                        rule_parser.con.dump(options.export_path)
+                        out_rules, in_rules = rule_parser.extract_export_parameters()
+                        export_settings(options.export_path, out_rules, in_rules)
+
+                    tc_params.update(rule_parser.get_tc_parameter())
+                    key = "{id} (device={veth})".format(id=container_info.id[:12], veth=veth,)
                     tc_params[key] = tc_params.pop(veth)
             else:
                 verify_network_interface(device, options.tc_command_output)
-
-                tc_params.update(
-                    TcShapingRuleParser(
-                        device, options.ip_version, options.tc_command_output, logger
-                    ).get_tc_parameter()
+                rule_parser = TcShapingRuleParser(
+                    device=device,
+                    ip_version=options.ip_version,
+                    tc_command_output=options.tc_command_output,
+                    logger=logger,
+                    export_path=options.export_path,
+                    is_parse_filter_id=not options.exclude_filter_id,
+                    dump_db_path=options.dump_db_path,
                 )
+                rule_parser.parse()
+
+                if options.export_path:
+                    rule_parser.con.dump(options.export_path)
+                    out_rules, in_rules = rule_parser.extract_export_parameters()
+                    export_settings(options.export_path, out_rules, in_rules)
+
+                tc_params.update(rule_parser.get_tc_parameter())
         except TargetNotFoundError as e:
-            logger.warn(e)
+            logger.warning(e)
             continue
 
     return tc_params
