@@ -1,10 +1,7 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import division, print_function, unicode_literals
 
 import pytest
 import typepy
@@ -12,8 +9,7 @@ from allpairspy import AllPairs
 from subprocrunner import SubprocessRunner
 
 from tcconfig._const import Tc
-
-from .common import execute_tcdel
+from tcconfig.traffic_control import delete_all_rules
 
 
 SKIP_TEST = False
@@ -37,8 +33,8 @@ def is_invalid_param(rate, delay, loss, corrupt):
     return all([typepy.is_null_string(param) for param in params])
 
 
-class NormalTestValue(object):
-    RATE_LIST = ["", "--rate 100K", "--rate 0.5M"]
+class NormalTestValue:
+    RATE_LIST = ["", "--rate 100Kbps", "--rate 0.5Mbps"]
     DELAY_LIST = ["", "--delay 100ms"]
     DELAY_DISTRO_LIST = ["", "--delay-distro 20ms"]
     PACKET_LOSS_RATE_LIST = ["", "--loss 0.1", "--loss 10%"]
@@ -50,11 +46,12 @@ class NormalTestValue(object):
     IPTABLES_LIST = ["", "--iptables"]
 
 
-class Test_tcconfig(object):
+class Test_tcconfig:
     """
     Tests in this class are not executable on CI services.
     Execute the following command at the local environment to running tests:
-      python setup.py test --addopts "--runxfail --device=<test device>"
+
+      pytest --runxfail --device=<test device>
 
     These tests are expected to execute on following environment:
        - Linux w/ iputils-ping package
@@ -116,7 +113,7 @@ class Test_tcconfig(object):
             pytest.skip("skip null parameters")
 
         for device_option in [device_value, "--device {}".format(device_value)]:
-            execute_tcdel(device_value)
+            delete_all_rules(device_value)
 
             command = " ".join(
                 [
@@ -138,4 +135,4 @@ class Test_tcconfig(object):
             tcset_proc = SubprocessRunner(command)
             assert tcset_proc.run() == 0, tcset_proc.stderr
 
-            execute_tcdel(device_value)
+            delete_all_rules(device_value)
