@@ -1,18 +1,17 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import
+
+import json
 
 import pytest
-import simplejson as json
 from subprocrunner import SubprocessRunner
 
 from tcconfig._const import Tc
+from tcconfig.traffic_control import delete_all_rules
 
-from .common import execute_tcdel, print_test_result
+from .common import print_test_result, runner_helper
 
 
 @pytest.fixture
@@ -20,12 +19,12 @@ def device_value(request):
     return request.config.getoption("--device")
 
 
-class Test_tcset_change(object):
+class Test_tcset_change:
     """
     Tests in this class are not executable on CI services.
     Execute the following command at the local environment to running tests:
 
-        python setup.py test --addopts "--device=<test device>"
+        pytest --device=<test device>
 
     These tests expected to execute in the following environment:
        - Linux w/ iputils-ping package
@@ -37,77 +36,61 @@ class Test_tcset_change(object):
             pytest.skip("device is null")
 
         for device_option in [device_value, "--device {}".format(device_value)]:
-            execute_tcdel(device_option)
+            delete_all_rules(device_option)
 
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            device_option,
-                            "--delay 100ms --rate 50k --network 192.168.1.2 --change",
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        device_option,
+                        "--delay 100ms --rate 50Kbps --network 192.168.1.2 --change",
+                    ]
+                )
+            )
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        device_option,
+                        "--delay 100ms --rate 50Kbps --network 192.168.1.3 --change",
+                    ]
+                )
             )
 
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            device_option,
-                            "--delay 100ms --rate 50k --network 192.168.1.3 --change",
-                        ]
-                    )
-                ).run()
-                == 0
-            )
-
-            execute_tcdel(device_option)
+            delete_all_rules(device_option)
 
     def test_normal(self, device_value):
         if device_value is None:
             pytest.skip("device is null")
 
         for device_option in [device_value, "--device {}".format(device_value)]:
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            device_option,
-                            "--delay 100ms --rate 50k --network 192.168.1.2 --overwrite",
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        device_option,
+                        "--delay 100ms --rate 50Kbps --network 192.168.1.2 --overwrite",
+                    ]
+                )
             )
-
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            device_option,
-                            "--delay 200.0ms",
-                            "--delay-distro 20",
-                            "--rate 100k",
-                            "--loss 0.01%",
-                            "--duplicate 5%",
-                            "--reorder 2%",
-                            "--network 192.168.1.3",
-                            "--add",
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        device_option,
+                        "--delay 200.0ms",
+                        "--delay-distro 20",
+                        "--rate 100Kbps",
+                        "--loss 0.01%",
+                        "--duplicate 5%",
+                        "--reorder 2%",
+                        "--network 192.168.1.3",
+                        "--add",
+                    ]
+                )
             )
 
             runner = SubprocessRunner("{:s} {:s}".format(Tc.Command.TCSHOW, device_option))
-            runner.run()
-
             expected = (
                 "{"
                 + '"{:s}"'.format(device_value)
@@ -133,33 +116,28 @@ class Test_tcset_change(object):
                     }
                 }"""
             )
-
+            runner.run()
             print_test_result(expected=expected, actual=runner.stdout, error=runner.stderr)
             assert json.loads(runner.stdout) == json.loads(expected)
 
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            device_option,
-                            "--delay 300ms",
-                            "--delay-distro 30",
-                            "--rate 200k",
-                            "--loss 0.02%",
-                            "--duplicate 5.5%",
-                            "--reorder 0.2%",
-                            "--network 192.168.1.3",
-                            "--change",
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        device_option,
+                        "--delay 300ms",
+                        "--delay-distro 30",
+                        "--rate 200Kbps",
+                        "--loss 0.02%",
+                        "--duplicate 5.5%",
+                        "--reorder 0.2%",
+                        "--network 192.168.1.3",
+                        "--change",
+                    ]
+                )
             )
 
             runner = SubprocessRunner("{:s} {:s}".format(Tc.Command.TCSHOW, device_option))
-            runner.run()
-
             expected = (
                 "{"
                 + '"{:s}"'.format(device_value)
@@ -185,9 +163,9 @@ class Test_tcset_change(object):
                     }
                 }"""
             )
-
+            runner.run()
             print_test_result(expected=expected, actual=runner.stdout, error=runner.stderr)
             assert json.loads(runner.stdout) == json.loads(expected)
 
             # finalize ---
-            execute_tcdel(device_option)
+            delete_all_rules(device_option)
