@@ -1,22 +1,19 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, division
 
 import itertools
 
 import pingparsing
 import pytest
 import typepy
-from subprocrunner import SubprocessRunner
 
 from tcconfig._const import Tc
 from tcconfig._netem_param import convert_rate_to_f
+from tcconfig.traffic_control import delete_all_rules
 
-from .common import ASSERT_MARGIN, DEADLINE_TIME, execute_tcdel
+from .common import ASSERT_MARGIN, DEADLINE_TIME, runner_helper
 
 
 @pytest.fixture
@@ -43,12 +40,12 @@ def pingparser():
     return pingparsing.PingParsing()
 
 
-class Test_tcset_one_network(object):
+class Test_tcset_one_network:
     """
     Tests in this class are not executable on CI services.
     Execute the following command at the local environment to running tests:
 
-        python setup.py test --addopts "--device=<test device> --dst-host=<IP address>"
+        pytest --device=<test device> --dst-host=<IP address>
 
     These tests expected to execute in the following environment:
        - Linux w/ iputils-ping package
@@ -67,9 +64,9 @@ class Test_tcset_one_network(object):
         if typepy.is_null_string(dst_host_option):
             pytest.skip("destination host is null")
 
-        for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/o latency tc ---
             ping_result = transmitter.ping()
@@ -77,18 +74,15 @@ class Test_tcset_one_network(object):
             without_tc_rtt_avg = pingparser.parse(ping_result).rtt_avg
 
             # w/ latency tc ---
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            tc_target,
-                            "--delay {}ms".format(delay),
-                            "--shaping-algo {:s}".format(shaping_algo),
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        tc_target,
+                        "--delay {}ms".format(delay),
+                        "--shaping-algo {:s}".format(shaping_algo),
+                    ]
+                )
             )
 
             ping_result = transmitter.ping()
@@ -100,7 +94,7 @@ class Test_tcset_one_network(object):
             assert rtt_diff > (delay * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(device_option)
+            delete_all_rules(device_option)
 
     @pytest.mark.parametrize(["delay", "delay_distro"], [[100, 50]])
     def test_dst_net_latency_distro(
@@ -109,9 +103,9 @@ class Test_tcset_one_network(object):
         if typepy.is_null_string(dst_host_option):
             pytest.skip("destination host is null")
 
-        for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/o latency tc ---
             ping_result = transmitter.ping()
@@ -121,20 +115,17 @@ class Test_tcset_one_network(object):
             without_tc_rtt_mdev = ping_stats.rtt_mdev
 
             # w/ latency tc ---
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            tc_target,
-                            "--delay",
-                            "{:d}ms".format(delay),
-                            "--delay-distro",
-                            "{:d}ms".format(delay_distro),
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        tc_target,
+                        "--delay",
+                        "{:d}ms".format(delay),
+                        "--delay-distro",
+                        "{:d}ms".format(delay_distro),
+                    ]
+                )
             )
 
             ping_result = transmitter.ping()
@@ -151,7 +142,37 @@ class Test_tcset_one_network(object):
             assert rtt_diff > (delay_distro * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
+
+    @pytest.mark.parametrize(["delay_distribution"], [["normal"], ["pareto"], ["paretonormal"]])
+    def test_latency_distribution(
+        self, device_option, dst_host_option, transmitter, delay_distribution
+    ):
+        if typepy.is_null_string(dst_host_option):
+            pytest.skip("destination host is null")
+
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
+
+            # w/ latency tc ---
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        tc_target,
+                        "--delay",
+                        "2ms",
+                        "--delay-distro",
+                        "5ms",
+                        "--delay-distribution",
+                        delay_distribution,
+                    ]
+                )
+            )
+
+            # finalize ---
+            delete_all_rules(tc_target)
 
     @pytest.mark.parametrize(["option", "value"], [["--loss", 10], ["--corrupt", 10]])
     def test_dst_net_packet_loss(
@@ -160,9 +181,9 @@ class Test_tcset_one_network(object):
         if typepy.is_null_string(dst_host_option):
             pytest.skip("destination host is null")
 
-        for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/o traffic shaping ---
             ping_result = transmitter.ping()
@@ -170,11 +191,8 @@ class Test_tcset_one_network(object):
             without_tc_loss_rate = pingparser.parse(ping_result).packet_loss_rate
 
             # w/ traffic shaping ---
-            assert (
-                SubprocessRunner(
-                    " ".join([Tc.Command.TCSET, tc_target, "{:s} {:f}".format(option, value)])
-                ).run()
-                == 0
+            runner_helper(
+                " ".join([Tc.Command.TCSET, tc_target, "{:s} {:f}".format(option, value)])
             )
 
             ping_result = transmitter.ping()
@@ -186,7 +204,7 @@ class Test_tcset_one_network(object):
             assert loss_diff > (value * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
 
     @pytest.mark.parametrize(["option", "value"], [["--duplicate", 50], ["--duplicate", "10%"]])
     def test_dst_net_packet_duplicate(
@@ -195,9 +213,9 @@ class Test_tcset_one_network(object):
         if typepy.is_null_string(dst_host_option):
             pytest.skip("destination host is null")
 
-        for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/o packet duplicate tc ---
             ping_result = transmitter.ping()
@@ -205,12 +223,7 @@ class Test_tcset_one_network(object):
             without_tc_duplicate_rate = pingparser.parse(ping_result).packet_duplicate_rate
 
             # w/ packet duplicate tc ---
-            assert (
-                SubprocessRunner(
-                    " ".join([Tc.Command.TCSET, tc_target, "{:s} {}".format(option, value)])
-                ).run()
-                == 0
-            )
+            runner_helper(" ".join([Tc.Command.TCSET, tc_target, "{:s} {}".format(option, value)]))
 
             ping_result = transmitter.ping()
             assert ping_result.returncode == 0
@@ -221,7 +234,7 @@ class Test_tcset_one_network(object):
             assert duplicate_rate_diff > (convert_rate_to_f(value) * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
 
     def test_dst_net_exclude_dst_network(
         self, device_option, dst_host_option, transmitter, pingparser
@@ -233,34 +246,30 @@ class Test_tcset_one_network(object):
 
         delay = 100
 
-        for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/ latency tc ---
-            command_list = [Tc.Command.TCSET, tc_target, "--delay {:d}ms".format(delay)]
-            assert SubprocessRunner(" ".join(command_list)).run() == 0
+            runner_helper([Tc.Command.TCSET, tc_target, "--delay", "{:d}ms".format(delay)])
 
             ping_result = transmitter.ping()
             assert ping_result.returncode == 0
             with_tc_rtt_avg = pingparser.parse(ping_result).rtt_avg
 
             # exclude certain network ---
-            assert (
-                SubprocessRunner(
-                    " ".join(
-                        [
-                            Tc.Command.TCSET,
-                            tc_target,
-                            "--exclude-dst-network {:s}/24".format(
-                                ".".join(dst_host_option.split(".")[:3] + ["0"])
-                            ),
-                            "--delay {:d}ms".format(delay),
-                            "--overwrite",
-                        ]
-                    )
-                ).run()
-                == 0
+            runner_helper(
+                " ".join(
+                    [
+                        Tc.Command.TCSET,
+                        tc_target,
+                        "--exclude-dst-network {:s}/24".format(
+                            ".".join(dst_host_option.split(".")[:3] + ["0"])
+                        ),
+                        "--delay {:d}ms".format(delay),
+                        "--overwrite",
+                    ]
+                )
             )
             without_tc_rtt_avg = pingparser.parse(transmitter.ping()).rtt_avg
 
@@ -269,4 +278,4 @@ class Test_tcset_one_network(object):
             assert rtt_diff > (delay * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
