@@ -1,10 +1,7 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, division
 
 import pingparsing
 import pytest
@@ -12,8 +9,9 @@ import typepy
 from subprocrunner import SubprocessRunner
 
 from tcconfig._const import Tc
+from tcconfig.traffic_control import delete_all_rules
 
-from .common import ASSERT_MARGIN, DEADLINE_TIME, execute_tcdel
+from .common import ASSERT_MARGIN, DEADLINE_TIME
 
 
 @pytest.fixture
@@ -45,13 +43,12 @@ def pingparser():
     return pingparsing.PingParsing()
 
 
-class Test_tcset_two_network(object):
+class Test_tcset_two_network:
     """
     Tests in this class are not executable on CI services.
     Execute the following command at the local environment to running tests:
 
-      python setup.py test --addopts "--device=<test device> \n
-          --dst-host=<hostname/IP-addr> --dst-host-ex=<hostname/IP-addr>"
+      pytest --device=<test device> --dst-host=<hostname/IP-addr> --dst-host-ex=<hostname/IP-addr>
 
     These tests expected to execute in the following environment:
        - Linux w/ iputils-ping package
@@ -73,8 +70,8 @@ class Test_tcset_two_network(object):
         if any([typepy.is_null_string(dst_host_option), typepy.is_null_string(dst_host_ex_option)]):
             pytest.skip("destination host is null")
 
-        for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
+        for tc_target in [device_option]:
+            delete_all_rules(tc_target)
             delay = 100
 
             # tc to specific network ---
@@ -88,11 +85,11 @@ class Test_tcset_two_network(object):
             assert SubprocessRunner(" ".join(command_list)).run() == 0
 
             # w/o tc network ---
-            transmitter.destination_host = dst_host_option
+            transmitter.destination = dst_host_option
             without_tc_rtt_avg = pingparser.parse(transmitter.ping().stdout).rtt_avg
 
             # w/ tc network ---
-            transmitter.destination_host = dst_host_ex_option
+            transmitter.destination = dst_host_ex_option
             with_tc_rtt_avg = pingparser.parse(transmitter.ping().stdout).rtt_avg
 
             # assertion ---
@@ -100,4 +97,4 @@ class Test_tcset_two_network(object):
             assert rtt_diff > (delay * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
