@@ -1,10 +1,7 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, division, print_function
 
 import itertools
 
@@ -14,8 +11,9 @@ import typepy
 from subprocrunner import SubprocessRunner
 
 from tcconfig._const import Tc, TrafficDirection
+from tcconfig.traffic_control import delete_all_rules
 
-from .common import ASSERT_MARGIN, DEADLINE_TIME, execute_tcdel
+from .common import ASSERT_MARGIN, DEADLINE_TIME
 
 
 @pytest.fixture
@@ -47,13 +45,12 @@ def pingparser():
     return pingparsing.PingParsing()
 
 
-class Test_tcset_one_network(object):
+class Test_tcset_one_network:
     """
     Tests in this class are not executable on CI services.
     Execute the following command at the local environment to running tests:
 
-        python setup.py test --addopts "--device=<test device> \n
-            --local-host <IP address> --dst-host=<IP address>"
+        pytest --device=<test device> --local-host <IP address> --dst-host=<IP address>
 
     These tests expected to execute in the following environment:
        - Linux w/ iputils-ping package
@@ -82,8 +79,8 @@ class Test_tcset_one_network(object):
             pytest.skip("destination host is null")
 
         for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/o latency tc ---
             without_tc_rtt_avg = pingparser.parse(transmitter.ping().stdout).rtt_avg
@@ -115,16 +112,15 @@ class Test_tcset_one_network(object):
             assert rtt_diff > (delay * ASSERT_MARGIN)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
 
 
-class Test_tcset_exclude(object):
+class Test_tcset_exclude:
     """
     Tests in this class are not executable on CI services.
     Execute the following command at the local environment to running tests:
 
-        python setup.py test --addopts "--device=<test device> \n
-            --local-host <IP address> --dst-host=<IP address>"
+        pytest --device=<test device> --local-host <IP address> --dst-host=<IP address>"
 
     These tests expected to execute in the following environment:
        - Linux w/ iputils-ping package
@@ -153,8 +149,8 @@ class Test_tcset_exclude(object):
             pytest.skip("destination host is null")
 
         for tc_target in [device_option, "--device {}".format(device_option)]:
-            execute_tcdel(tc_target)
-            transmitter.destination_host = dst_host_option
+            delete_all_rules(tc_target)
+            transmitter.destination = dst_host_option
 
             # w/o latency tc ---
             without_tc_rtt_avg = pingparser.parse(transmitter.ping().stdout).rtt_avg
@@ -188,4 +184,4 @@ class Test_tcset_exclude(object):
             assert rtt_diff < (delay / 10)
 
             # finalize ---
-            execute_tcdel(tc_target)
+            delete_all_rules(tc_target)
